#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pretty-show
version:              1.10
visibility:           public
id:                   pretty-show-1.10-jI5AqYpLoz98dMARTaePi
key:                  pretty-show-1.10-jI5AqYpLoz98dMARTaePi
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
homepage:             http://wiki.github.com/yav/pretty-show
synopsis:
    Tools for working with derived `Show` instances and generic
    inspection of values.

description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.

category:             Text
abi:                  5262a171c43914f5428e5125681eadc9
exposed:              True
exposed-modules:      Text.Show.Pretty
hidden-modules:
    Text.Show.Html Text.Show.Parser Text.Show.Value Text.Show.PrettyVal
    Paths_pretty_show

import-dirs:          /usr/lib/ghc-8.10.5/site-local/pretty-show-1.10
library-dirs:         /usr/lib/ghc-8.10.5/site-local/pretty-show-1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-show
hs-libraries:         HSpretty-show-1.10-jI5AqYpLoz98dMARTaePi
depends:
    array-0.5.4.0 base-4.14.2.0 filepath-1.4.2.1 ghc-prim-0.6.1
    haskell-lexer-1.1-7oPlfVo8NPkJMo7wLz4t6q pretty-1.1.3.6
    text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html:         /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

